@@ -69,6 +69,11 @@ func main() {
 			Usage: "set this option if you want to create file instead of directory.\n" +
 				"for example, if you want to generate files with \".go\" extension: \"-e .go\"",
 		},
+		&cli.StringFlag{
+			Name:        "target-dir",
+			Usage:       "set this option if you want to specify the directory you want to make directory.",
+			DefaultText: "current directory",
+		},
 	}
 
 	verifyFlags := []cli.Flag{
@@ -110,8 +115,9 @@ func main() {
 
 	app := &cli.App{
 		Name: "gtree",
-		Usage: "This CLI uses Markdown to generate directory trees and directories itself, and also verifies directories.\n" +
-			fmt.Sprintf("The symbols that can be used in Markdown are '%s', '%s', '%s', and '%s'.", green("-"), green("+"), green("*"), green("#")),
+		Usage: "This CLI uses Markdown to generate directory trees and directories itself, and also verifies directories." + "\n" +
+			fmt.Sprintf("The symbols that can be used in Markdown are '%s', '%s', '%s', and '%s'.", green("-"), green("+"), green("*"), green("#")) + "\n" +
+			"Within Markdown, indentation represents hierarchy. The indentation can be whatever you specify, but use the same pattern.",
 		Version: fmt.Sprintf("%s / revision %s", Version, Revision),
 		Commands: []*cli.Command{
 			{
@@ -246,7 +252,7 @@ func actionMkdir(c *cli.Context) error {
 		defer in.Close()
 	}
 
-	options := []gtree.Option{gtree.WithFileExtensions(c.StringSlice("extension"))}
+	options := []gtree.Option{gtree.WithTargetDir(c.String("target-dir")), gtree.WithFileExtensions(c.StringSlice("extension"))}
 	if c.Bool("massive") {
 		options = append(options, gtree.WithMassive(context.Background()))
 	}
